@@ -7,6 +7,30 @@ app = Commander("mtx-drawer")
 rt_path = os.path.abspath(os.getcwd())
 
 
+@app.custom_complete("font_color")
+def draw_one():
+    return ["black", "white", "red", "green", "blue", "yellow", "cyan", "magenta"]
+
+@app.custom_complete("img_format")
+def draw_one():
+    return ["svg", "png", "jpg", "jpeg", "bmp", "eps"]
+
+@app.custom_complete("ops")
+def draw_one():
+    return ['abs', 'log', 'aver', 'real']
+
+@app.custom_complete('font_color')
+def draw():
+    return ["black", "white", "red", "green", "blue", "yellow", "cyan", "magenta"]
+
+@app.custom_complete('img_format')
+def draw():
+    return ["svg", "png", "jpg", "jpeg", "bmp", "eps"]
+
+@app.custom_complete('ops')
+def draw():
+    return ['abs', 'log', 'aver', 'real']
+
 @app.command()
 def draw_one(
     filepath: str,
@@ -15,6 +39,9 @@ def draw_one(
     log_times: int = 2,
     mat_size: int = 200,
     block_size: int = -1,
+    img_format: str = "svg",
+    font_color: str = "black",
+    show_in_console: bool = False,
 ):
     """
     单个文件处理
@@ -24,10 +51,13 @@ def draw_one(
     :param log_times: 取log次数
     :param mat_size: 缩略图尺寸
     :param block_size: 设置块大小（此参数设置后将覆盖mat_size）
+    :param img_format: 图片格式
+    :param font_color: 字体颜色
+    :param show_in_console: 是否在控制台显示图像, 如果为True则不会保存图像
     :return:
     """
+    status("处理").start()
     try:
-        status("处理").start()
         drawer = Drawer(
             filepath,
             "aver" in ops,
@@ -35,12 +65,15 @@ def draw_one(
             log_times,
             set_mat_size=mat_size,
             set_block_size=block_size,
+            img_format=img_format,
+            font_color=font_color,
+            show_in_console=show_in_console,
         )
-        status.stop()
     except ValueError:
         return
     for func in ops:
         drawer.call(func)
+    status.stop()
 
 
 @app.command()
@@ -50,6 +83,8 @@ def draw(
     log_times: int = 2,
     mat_size: int = 200,
     block_size: int = -1,
+    img_format: str = "svg",
+    font_color: str = "black",
 ):
     """
     多个文件处理
@@ -74,6 +109,8 @@ def draw(
                         log_times,
                         set_mat_size=mat_size,
                         set_block_size=block_size,
+                        img_format=img_format,
+                        font_color=font_color,
                     )
                     for func in ops:
                         drawer.call(func)
